/*-------------------------------------------------------------------
Name......... devmgr.h
Author....... Marc Adams
Date......... 10/09/03
Description.. Header file for the device manager
-------------------------------------------------------------------*/

/*-------------------------------------------------------------------
DECLARATION FORMATS
Type defs........... UPPER CASE
#defines............ UPPER CASE
Global Functions.... GlobalFunction();
Static Functions.... staticfunction();
Global Variables.... GlobalVariable;
Static Variables.... staticvariable;
Local Variables..... localvariable;
Structure Elements.. Structure.element;
-------------------------------------------------------------------*/


#ifndef HARDWARE_DEVMGR
#define HARDWARE_DEVMGR

/****	Defines */

#define	ERR_RESET	0x80

/****	Type Definitions */


typedef	UBYTE	ERRBIT;

typedef	struct	errvar
{
	ERRBIT	errors;
	ERRBIT	errmask;
	BYTE	line;
} ERRVAR;

typedef	struct devstatus
{
	UBYTE	type;
	UBYTE	id;
	ERRBIT	error;
	UBYTE	line;
} DEVSTATUS;

typedef	struct errstatus
{
	ERRBIT	errors;
	UBYTE	line;
} ERRSTATUS;

typedef	struct device
{
	BYTE		type;
	BYTE		id;
	BYTE		lines;

	BYTE		(*install)(const struct device* dev,WORD cfg,WORD base);
	void		(*shutdown)(const struct device* dev);
	void		(*restore)(const struct device* dev);

	void*		vars;
	void*		zvars;
	ERRVAR*		errvar;

	const void*	config;
	const void*	services;
	const void*	errordata;
} DEVICE;

typedef	struct	installdevice
{
	const	DEVICE*	device;
	WORD	(*deviceselect)();
	WORD	(*configselect)();
	const 	void*	optionlist;
} INSTALLDEVICE;

typedef	struct	buildtype
{
	const	DEVICE**	devicelist;
	BYTE				devicetype;
} BUILDTYPE;

/****	Prototypes */

#include	"devmgr.p"

#endif
/*************************************************************************/
