/*-------------------------------------------------------------------
Name......... dmamod.h
Author....... Marc Adams
Date......... 01/08/03
Description.. Header file for the Coldfire DMA module
-------------------------------------------------------------------*/

/*-------------------------------------------------------------------
DECLARATION FORMATS
Type defs........... UPPER CASE
#defines............ UPPER CASE
Global Functions.... GlobalFunction();
Static Functions.... staticfunction();
Global Variables.... GlobalVariable;
Static Variables.... staticvariable;
Local Variables..... localvariable;
Structure Elements.. Structure.element;
-------------------------------------------------------------------*/


#ifndef HARDWARE_DMAMOD
#define HARDWARE_DMAMOD

/****	Defines */


/* Channel 1 base address */
#define	DMA1_BASE	(MBAR+0x200)
/* Channel 2 base address */
#define	DMA2_BASE	(MBAR+0x240)

/* Channel 1 Registers */
/* source address */
#define DMA1_SAR	REGLV(DMA1_BASE)
/* destination address register */
#define DMA1_DAR	REGLV(DMA1_BASE+0x04)
/* channel control register */
#define DMA1_DCR	REGWV(DMA1_BASE+0x08)
/* byte count register */
#define DMA1_BCR	REGWV(DMA1_BASE+0x0C)
/* channel status register */
#define DMA1_DSR	REGBV(DMA1_BASE+0x10)
/* interrupt vector register */
#define DMA1_DIVR	REGBV(DMA1_BASE+0x14)

/* Channel 2 Registers */
/* source address */
#define DMA2_SAR	REGLV(DMA2_BASE)
/* destination address register */
#define DMA2_DAR	REGLV(DMA2_BASE+0x04)
/* channel control register */
#define DMA2_DCR	REGWV(DMA2_BASE+0x08)
/* byte count register */
#define DMA2_BCR	REGWV(DMA2_BASE+0x0C)
/* channel status register */
#define DMA2_DSR	REGBV(DMA2_BASE+0x10)
/* interrupt vector register */
#define DMA2_DIVR	REGBV(DMA2_BASE+0x14)

#define	DMA_DONE_BIT	0x01

#define	DMA_START 		0x01

#define	DONE			0x01
#define	BES				0x20
#define	BED				0x10
#define	CONF			0x40
#define	DMA_STS_BITS	(DONE+BES+BED+CONF)

/****	Type Definitions */

typedef	struct
{
	UWORD	dcr;
	UBYTE	divr;
} DMACFG;

/****	Prototypes */

	#include	"dmamod.p"

#endif
/*************************************************************************/
