/*-------------------------------------------------------------------
Name......... entry.h
Author....... Marc Adams
Date......... 16/09/03
Description.. 5206E Coldfire constants
-------------------------------------------------------------------*/

/*-------------------------------------------------------------------
DECLARATION FORMATS
Type defs........... UPPER CASE
#defines............ UPPER CASE
Global Functions.... GlobalFunction();
Static Functions.... staticfunction();
Global Variables.... GlobalVariable;
Static Variables.... staticvariable;
Local Variables..... localvariable;
Structure Elements.. Structure.element;
-------------------------------------------------------------------*/

/******************************	ASSEMBLY LEVEL CONSTANTS	*/
/*	5206E CONSTANTS	*/

	.EQU	CPU_ADS_FC, 0x00000007	/* CPU ADDR SPACE FUNCTION CODE */
	.EQU	MBARV_BT, 	0x00000001	/* VALID ADDRESS BIT */
	.EQU	MBARV_BN,	0x00000000	/* VALID ADDRESS BIT NUMBER */

	.EQU	VECTORS,	0X00000000

	.EQU	MBAR,		0xF0000000	/* MBAR Base Address Module */

/***	First Stage Security Range */
/* In the enhanced security design this is fixed to the full 512KB range */
	.EQU	SecBootStart,	0x00000000
	.EQU	SecBootEnd,		0x00080000

/* CHIP SELECT REGISTERS */

	/* Chip select 0 */
	.EQU	CSAR0,		MBAR+0x64
	.EQU	CSAMR0,		MBAR+0x68
	.EQU	CSCR0,		MBAR+0x6E
	/* Chip select 1 */
	.EQU	CSAR1,		MBAR+0x70
	.EQU	CSAMR1,		MBAR+0x74
	.EQU	CSCR1,		MBAR+0x7A
	/* Chip select 2 */
	.EQU	CSAR2,		MBAR+0x7C
	.EQU	CSAMR2,		MBAR+0x80
	.EQU	CSCR2,		MBAR+0x86
	/* Chip select 3 */
	.EQU	CSAR3,		MBAR+0x88
	.EQU	CSAMR3,		MBAR+0x8C
	.EQU	CSCR3,		MBAR+0x92
	/* Chip select 4 */
	.EQU	CSAR4,		MBAR+0x94
	.EQU	CSAMR4,		MBAR+0x98
	.EQU	CSCR4,		MBAR+0x9e
	/* Chip select 5 */
	.EQU	CSAR5,		MBAR+0xA0
	.EQU	CSAMR5,		MBAR+0xA4
	.EQU	CSCR5,		MBAR+0xAA
	/* Chip select 6 */
	.EQU	CSAR6,		MBAR+0xAC
	.EQU	CSAMR6,		MBAR+0xB0
	.EQU	CSCR6,		MBAR+0xB6
	/* Chip select 7 */
	.EQU	CSAR7,		MBAR+0xB8
	.EQU	CSAMR7,		MBAR+0xBC
	.EQU	CSCR7,		MBAR+0xC2
	/* Default memory control register */
	.EQU	DMCR,		MBAR+0xC6

/* DRAM CONTROLLER REGISTERS */

	.EQU	DCRR,		MBAR+0x46
	.EQU	DCTR,		MBAR+0x4A
	/* DRAM bank 0 */
	.EQU	DCAR0,		MBAR+0x4C
	.EQU	DCMR0,		MBAR+0x50
	.EQU	DCCR0,		MBAR+0x57
	/* DRAM bank 1 */
	.EQU	DCAR1,		MBAR+0x58
	.EQU	DCMR1,		MBAR+0x5C
	.EQU	DCCR1,		MBAR+0x63

/* SIM MODULE CONTROLLER REGISTERS */
	.EQU	SIMR,		MBAR+0x03
	.EQU	ICR1,		MBAR+0x14
	.EQU	ICR2,		MBAR+0x15
	.EQU	ICR3,		MBAR+0x16
	.EQU	ICR4,		MBAR+0x17
	.EQU	ICR5,		MBAR+0x18
	.EQU	ICR6,		MBAR+0x19
	.EQU	ICR7,		MBAR+0x1A
	.EQU	ICR8,		MBAR+0x1B
	.EQU	ICR9,		MBAR+0x1C
	.EQU	ICR10,		MBAR+0x1D
	.EQU	ICR11,		MBAR+0x1E
	.EQU	ICR12,		MBAR+0x1F
	.EQU	ICR13,		MBAR+0x20
	.EQU	ICR14,		MBAR+0x21
	.EQU	ICR15,		MBAR+0x22
	.EQU	IMR,		MBAR+0x36
	.EQU	IPR,		MBAR+0x3A
	.EQU	RSR,		MBAR+0x40
	.EQU	SYPCR,		MBAR+0x41
	.EQU	SWIVR,		MBAR+0x42
	.EQU	SWSR,		MBAR+0x43
	.EQU	PAR,		MBAR+0xCA
	.EQU	MARB,		MBAR+0x07

/***	Ram Clear Bits */
/* These bit definitions must correspond to those defined in Memory.h */
/* Change these EQUates for constant bytes */

	.EQU	SYSTEM_BIT,		0
	.EQU	VARS_BIT,		1
	.EQU	ZEROVARS_BIT,	2
	.EQU	STACK_BIT,		3		/* STACK BIT CLEAR HEAP AS WELL */
	.EQU	SAFE_BIT,		4

/***************************************************************************/




