/*-------------------------------------------------------------------
Name......... fpuart.h
Author....... Marc Adams
Date......... 08/09/03
Description.. Header file for the generic FPGA UART device driver
-------------------------------------------------------------------*/

/*-------------------------------------------------------------------
DECLARATION FORMATS
Type defs........... UPPER CASE
#defines............ UPPER CASE
Global Functions.... GlobalFunction();
Static Functions.... staticfunction();
Global Variables.... GlobalVariable;
Static Variables.... staticvariable;
Local Variables..... localvariable;
Structure Elements.. Structure.element;
-------------------------------------------------------------------*/
#ifndef HARDWARE_FPUART
#define HARDWARE_FPUART
/****	Defines */

/* Control Register Bits */
/* Write */
#define CLEAR_TX_INT	0x01
/* Read */
#define TX_INT			0x01
/* Write */
#define CLEAR_RX_INT	0x02
/* Read */
#define	RX_INT			0x02
/* Write/Read */
#define ENABLE_TX_INT	0x04
#define ENABLE_RX_INT	0x08
/* Write */
#define RTS_BIT			0x10
/* Read */
#define CTS_BIT			0x10
#define FRAME_ERROR		0x20
#define PARITY_ERROR	0x40

/* Format Register Bits */
/* Bits 0-2 determine Baud Rate and are defined below */
/* Bit 3 reserved */
/* Bit 4 enable parity checking */
#define PARITY_ENABLE	0x10
/* Bit 5 parity odd/even */
#define PARITY_ODD_EVEN	0x20
/* Bit 6 number of data bits */
#define DATA_BITS		0x40
/* Bit 7 number of stop bits */
#define STOP_BITS		0x80

/* Baud Rate Settings using bits 0-2 of the format register */
#define BAUD_1200_MASK	0x00 /* 00000000 */
#define BAUD_2400_MASK	0x01 /* 00000001 */
#define BAUD_4800_MASK	0x02 /* 00000010 */
#define BAUD_9600_MASK	0x03 /* 00000011 */
#define BAUD_19200_MASK	0x04 /* 00000100 */

#define	PARITYEVEN	0x00
#define	PARITYODD	0x04
#define	PARITYNONE	0x10

#define	BITS7		0x02
#define	BITS8		0x03

#define	STOP1		0x07
#define	STOP2		0x0f

/* Routes */
#define BACTA   0x00
#define RS232A  0x01
#define RS232C  0x02
#define RS232D  0x03
#define CCTALK1 0x04
#define CCTALK2 0x05
#define TTL		0x06
#define RS485	0x07

#define CTRLMODIFYMASK 0x0C

/****	Type Definitions */

/* write registers */
typedef	struct regfpuartwr
{
	/* control reg */
	volatile	UBYTE	uctrl;
	/* transmit buffer reg */
	volatile	UBYTE	utx;
	/* routing reg */
	volatile	UBYTE	uroute;
	/* format reg */
	volatile 	UBYTE 	ufrmt;
} REGFPUARTW;

/* read registers */
typedef	struct regfpuartr
{
	/* control reg */
	volatile	UBYTE	uctrl;
	/* receive buffer reg */
	volatile	UBYTE	urx;
	/* format reg */
	volatile 	UBYTE 	ufrmt;
} REGFPUARTR;

/* UART */
typedef	union	regfpuart
{
	REGFPUARTR	read;
	REGFPUARTW	write;
} REGFPUART;

typedef	struct ramfpuartw
{
	volatile	UBYTE	mr1a;
	volatile	UBYTE	mr2a;
	volatile	UBYTE	csra;

	volatile	UBYTE	mr1b;
	volatile	UBYTE	mr2b;
	volatile	UBYTE	csrb;

	volatile	UBYTE	acr;
	volatile	UBYTE	ier;
} RAMFPUARTW;

typedef	struct	fpuartcfg
{
	void*		base;
	void		(*isr)();
	BYTE*		txbuffer;
	BYTE*		rxbuffer;
	BYTE		txmask;
	BYTE		rxmask;
} FPUARTCFG;

typedef	struct	fpuartvars
{
	const FPUARTCFG*	config;
	REGFPUART*		base;
	RAMFPUARTW		regs;
	UBYTE	txin;
	UBYTE	txout;
	UBYTE	txmask;
	UBYTE	rxin;
	UBYTE	rxout;
	UBYTE	rxmask;
	UBYTE*	txbuffer;
	UBYTE*	rxbuffer;
} FPUARTVARS;

typedef	struct fpuartservices
{
	BYTE	(*configure)(const DEVICE* dev,BYTE txbaud,BYTE rxbaud,BYTE data,BYTE stop,BYTE parity,BYTE txhs ,BYTE rxhs);
	BYTE	(*tx)(const DEVICE* dev,char ch);
	WORD	(*rx)();
	BYTE 	(*txempty)();
	BYTE 	(*rxempty)();
	void 	(*cleartx)();
	void 	(*clearrx)();
	void	(*setrouting)(const DEVICE* dev, BYTE channel, BYTE route);
} FPUARTSERVICES;

/****	Prototypes */

#include	"fpuart.p"

#endif

/*************************************************************************/
