	/*-------------------------------------------------------------------
Name......... lamps.h
Author....... Marc Adams
Date......... 29/07/03
Description.. Header file for the dimming lamps device driver
-------------------------------------------------------------------*/

/*-------------------------------------------------------------------
DECLARATION FORMATS
Type defs........... UPPER CASE
#defines............ UPPER CASE
Global Functions.... GlobalFunction();
Static Functions.... staticfunction();
Global Variables.... GlobalVariable;
Static Variables.... staticvariable;
Local Variables..... localvariable;
Structure Elements.. Structure.element;
-------------------------------------------------------------------*/

#ifndef HARDWARE_LAMPS
#define HARDWARE_LAMPS

/****	Defines */

	#define	MPX1		0x0000
	#define	MPX2		0x1000
	#define	NOF_STROBES	16
	#define	STROBEMASK	0x01e0
	#define ROWMASK		0x001f

	#define	DUM_LAMP	-1
	#define	DUM_STATUS	-1
	#define	EOF_LAMPS	-2
	#define	FLASHSIZE	(sizeof(MPXSTROBE) * 16)

	#define	EOF_DIGITS	 -1

	#define	FPH00	0x01
	#define	FPH01	0x02
	#define	FPH10	0x04
	#define	FPH11	0x08
	#define	FPH20	0x10
	#define	FPH21	0x20
	#define	FPH30	0x40
	#define	FPH31	0x80

	#define	FPH0	(FPH00 | FPH01)
	#define	FPH1	(FPH10 | FPH11)
	#define	FPH2	(FPH20 | FPH21)
	#define	FPH3	(FPH30 | FPH31)

	#define	OFF		0
	#define	ON		(FPH00 | FPH01 | FPH10 | FPH11 | FPH20 | FPH21 | FPH30 | FPH31)
	#define	F1		(FPH00 | FPH01 | FPH10 | FPH11)
	#define	F2		(FPH20 | FPH21 | FPH30 | FPH31)
	#define	FF1		(FPH00 | FPH01 | FPH20 | FPH21)
	#define	FF2		(FPH10 | FPH11 | FPH30 | FPH31)

	#define	PERIOD0		(FPH00 | FPH10 | FPH20 | FPH30)
	#define	PERIOD1		(FPH01 | FPH11 | FPH21 | FPH31)


	#define	LAMP(STR,ROW)	(MPX1 | (32*STR + ROW))

	/* Lamp columns */
	#define	LC0		0
	#define	LC1		1
	#define	LC2		2
	#define	LC3		3
	#define	LC4		4
	#define	LC5		5
	#define	LC6		6
	#define	LC7		7
	#define	LC8		8
	#define	LC9		9
	#define	LC10	10
	#define	LC11	11
	#define	LC12	12
	#define	LC13	13
	#define	LC14	14
	#define	LC15	15

	/* Lamp rows */
	#define	LR0		0
	#define	LR1		1
	#define	LR2		2
	#define	LR3		3
	#define	LR4		4
	#define	LR5		5
	#define	LR6		6
	#define	LR7		7
	#define	LR8		8
	#define	LR9		9
	#define	LR10	10
	#define	LR11	11
	#define	LR12	12
	#define	LR13	13
	#define	LR14	14
	#define	LR15	15

	/* Multiplexed LEDS */
	#define	LED0	(MPX1 | (32*0 + 16))
	#define	LED1	(MPX1 | (32*1 + 16))
	#define	LED2	(MPX1 | (32*2 + 16))
	#define	LED3	(MPX1 | (32*3 + 16))
	#define	LED4	(MPX1 | (32*4 + 16))
	#define	LED5	(MPX1 | (32*5 + 16))
	#define	LED6	(MPX1 | (32*6 + 16))
	#define	LED7	(MPX1 | (32*7 + 16))
	#define	LED8	(MPX1 | (32*8 + 16))
	#define	LED9	(MPX1 | (32*9 + 16))
	#define	LED10	(MPX1 | (32*10 + 16))
	#define	LED11	(MPX1 | (32*11 + 16))
	#define	LED12	(MPX1 | (32*12 + 16))
	#define	LED13	(MPX1 | (32*13 + 16))
	#define	LED14	(MPX1 | (32*14 + 16))
	#define	LED15	(MPX1 | (32*15 + 16))
	#define	LED16	(MPX1 | (32*0 + 24))
	#define	LED17	(MPX1 | (32*1 + 24))
	#define	LED18	(MPX1 | (32*2 + 24))
	#define	LED19	(MPX1 | (32*3 + 24))
	#define	LED20	(MPX1 | (32*4 + 24))
	#define	LED21	(MPX1 | (32*5 + 24))
	#define	LED22	(MPX1 | (32*6 + 24))
	#define	LED23	(MPX1 | (32*7 + 24))
	#define	LED24	(MPX1 | (32*8 + 24))
	#define	LED25	(MPX1 | (32*9 + 24))
	#define	LED26	(MPX1 | (32*10 + 24))
	#define	LED27	(MPX1 | (32*11 + 24))
	#define	LED28	(MPX1 | (32*12 + 24))
	#define	LED29	(MPX1 | (32*13 + 24))
	#define	LED30	(MPX1 | (32*14 + 24))
	#define	LED31	(MPX1 | (32*15 + 24))

	/* */
	#define	DIG0 	0
	#define	DIG1 	1
	#define	DIG2 	2
	#define	DIG3 	3
	#define	DIG4 	4
	#define	DIG5 	5
	#define	DIG6 	6
	#define	DIG7 	7
	#define	DIG8	8
	#define	DIG9	9
	#define	DIG10	10
	#define	DIG11	11
	#define	DIG12	12
	#define	DIG13	13
	#define	DIG14	14
	#define	DIG15	15

	/* LED segments */
	#define	SEG0 	0x01
	#define	SEG1 	0x02
	#define	SEG2 	0x04
	#define	SEG3 	0x08
	#define	SEG4 	0x10
	#define	SEG5 	0x20
	#define	SEG6 	0x40
	#define	SEG7 	0x80

/****	Type Definitions */

typedef	WORD LAMP;
typedef	WORD DIGIT;
typedef	WORD STATUS;

typedef	struct	lampscfg
{
	BYTE flashtime;
	BYTE brightness;
} LAMPSCFG;

typedef	struct	mpxstrobe
{
	LONG mpx1period0;
	LONG mpx1period1;
	LONG mpx1period2;
	LONG mpx1period3;
	LONG mpx1period4;
	LONG mpx1period5;
	LONG mpx1period6;
	LONG mpx1period7;
	BYTE brightness[31];
} MPXSTROBE;

typedef	struct	lampzvars
{
	struct lampzvars*	next;
	MPXSTROBE mpx[NOF_STROBES*4];		/* strobes x4 flash phases */
	BYTE flashtime;
} LAMPZVARS;

typedef	struct	lampvars
{
	volatile WORD strobeidx;
	WORD flashidx;
	WORD flashoffset;
	const LAMPSCFG*	config;
} LAMPVARS;


typedef	struct	lampservices
{
	void (*Lamp)(const LAMP lp);
} LAMPSERVICES;

/****	Prototypes */

	#include	"lamps.p"

#endif
/*******************************************************************/
