/*-------------------------------------------------------------------
Name......... mbusdev.h
Author....... Marc Adams
Date......... 05/08/03
Description.. Header file for the Coldfire Mbus driver
-------------------------------------------------------------------*/

/*-------------------------------------------------------------------
DECLARATION FORMATS
Type defs........... UPPER CASE
#defines............ UPPER CASE
Global Functions.... GlobalFunction();
Static Functions.... staticfunction();
Global Variables.... GlobalVariable;
Static Variables.... staticvariable;
Local Variables..... localvariable;
Structure Elements.. Structure.element;
-------------------------------------------------------------------*/

#ifndef HARDWARE_MBUSDEV
#define HARDWARE_MBUSDEV

/****	Defines */

#define	MBUSBASE	(MBAR+0x1E0)

#define MADR		REGBV(MBUSBASE)			/* Address register */
#define MFDR		REGBV(MBUSBASE+0x04)	/* Frequency divider */
#define MBCR		REGBV(MBUSBASE+0x08)	/* Control register */
#define MBSR		REGBV(MBUSBASE+0x0C)	/* Status register */
#define MBDR		REGBV(MBUSBASE+0x10)	/* Data register */

/* Contol Register Bits */
#define MEN		0x80	/* Enable */
#define MIEN	0x40	/* Interrupt enable */
#define MSTA	0x20	/* Master/Slave detect */
#define MTX		0x10	/* Transmit/Receive */
#define TXAK	0x08	/* Transmit Acknowledge */
#define RSTA	0x04	/* Repeat Start */

/* Status Register Bits */
#define MBB		0x20	/* Busy Busy */
#define MIF		0x02	/* Interrupt pending */
#define RXAK	0x01	/* Receive Acknowledge */


/****	Type Definitions */
typedef	struct	mbuscfg
{
	BYTE	madr;	/* Address register */
	BYTE	mfdr;	/* Frequency divider */
	BYTE	mbcr;	/* Control register */
} MBUSCFG;

/* External services provided by the Mbus driver */
typedef	struct	mbusservices
{
	/* I2C read */
	BYTE (*mbusread)(BYTE device_address, BYTE internal_addr,
			  	    BYTE *destination, LONG byte_count);
	/* I2C write */
	BYTE (*mbuswrite)(const BYTE* source, LONG byte_count,
					 BYTE device_address, BYTE internal_address);
} MBUSSERVICES;

/****	Prototypes */

	#include	"mbusdev.p"

#endif
/*************************************************************************/
