/*-------------------------------------------------------------------
Name......... pic18.h
Author....... Marc Adams
Date......... 24/07/03
Description.. Header file for the PIC18 CSD
-------------------------------------------------------------------*/

/*-------------------------------------------------------------------
DECLARATION FORMATS
Type defs........... UPPER CASE
#defines............ UPPER CASE
Global Functions.... GlobalFunction();
Static Functions.... staticfunction();
Global Variables.... GlobalVariable;
Static Variables.... staticvariable;
Local Variables..... localvariable;
Structure Elements.. Structure.element;
-------------------------------------------------------------------*/

#ifndef HARDWARE_PIC18
#define HARDWARE_PIC18

/****	Defines */

/* counter used to re-order RTC bytes */
#define	TIME_COUNTER		3

/* PIC data address codes */
#define	RTC_DATA			0x00
#define	SWITCH_LOG_DATA_1	0x01
#define	SWITCH_LOG_DATA_2	0x02
#define	SWITCH_LOG_DATA_3	0x03
#define	SWITCH_LOG_DATA_4	0x04
#define	SWITCH_LOG_DATA_5	0x05
#define	SWITCH_LOG_DATA_6	0x06
#define	SWITCH_LOG_DATA_7	0x07
#define	SWITCH_LOG_DATA_8	0x08
#define	SWITCH_LOG_DATA_9	0x09
#define	SWITCH_LOG_DATA_10	0x0A
#define	CLEAR_SWITCH_LOG	0x0B
#define	PERCENT_KEY_DATA	0x0C
#define	STAKE_PRIZE_DATA	0x0D
#define	DIL_SWITCH_1_DATA	0x0E
#define	DIL_SWITCH_2_DATA	0x0F
#define STATUS_BYTE			0x10
#define CSD_REVISION		0x11
#define PIC_SIG				0x12
#define RTC_DATA_FINE		0x13
#define EEPROM_WRITE		0x14
#define EEPROM_READ			0x15

/* PIC data lengths */
#define	LOG_DATA_SIZE			0x05
#define	RTC_SIZE				0x04
#define	PERCENT_DATA_SIZE		0x01
#define	STAKE_PRIZE_DATA_SIZE	0x01
#define	DIL_1_DATA_SIZE			0x01
#define	DIL_2_DATA_SIZE			0x01
#define REVISION_DATA_SIZE		0x01
#define PIC_SIG_SIZE           	0x01
#define	RTC_SIZE_FINE			0x05
#define SERIALNUM_DATA_SIZE		0x08

/* Security Switches Error code */
#define	ERR_MBUS_FAIL			0x02
#define ERR_RECORD_EMPTY		0x03
#define	ERR_WRONG_INDEX			0x04

/* Serial number data read/write error codes */
#define EER_DATA_SIZE			0x05

/* Bit counts for shifting the fine granularity
   time into a LONG */
#define UP_1_BYTE				8

/****	Type Definitions */

typedef	struct	pic18cfg
{
	const	DEVICE*	MbusDevice;
	BYTE	Mbusaddr;
} PIC18CFG;

typedef	struct	pic18vars
{
	const	PIC18CFG* config;
} PIC18VARS;

typedef	union
{
	ULONG	integer;
	struct
	{
		BYTE	byte4;
		BYTE	byte3;
		BYTE	byte2;
		BYTE	byte1;
	} log;
} PIC18RTC;

typedef	struct pic18rtcfine
{
	BYTE	byte5;
	BYTE	byte4;
	BYTE	byte3;
	BYTE	byte2;
	BYTE	byte1;
} PIC18RTCFINE;

typedef	union
{
	ULONG	integer;
	struct
	{
		BYTE	byte4;
		BYTE	byte3;
		BYTE	byte2;
		BYTE	byte1;
		BYTE	switchreading;
	} log;
} PIC18LOG;

typedef	struct	pic18time
{
	WORD	year;
	BYTE	month;
	BYTE	weekday;
	BYTE	date;
	BYTE	hours;
	BYTE	minutes;
	BYTE	seconds;
	UBYTE	hundredths;
} P18TIME;


/****	Prototypes */

	#include	"pic18.p"

#endif
/*******************************************************************/
