/*-------------------------------------------------------------------
Name......... serialmod.h
Author....... Marc Adams
Date......... 01/09/03
Description.. Header file for the Coldfire Serial Module
-------------------------------------------------------------------*/

/*-------------------------------------------------------------------
DECLARATION FORMATS
Type defs........... UPPER CASE
#defines............ UPPER CASE
Global Functions.... GlobalFunction();
Static Functions.... staticfunction();
Global Variables.... GlobalVariable;
Static Variables.... staticvariable;
Local Variables..... localvariable;
Structure Elements.. Structure.element;
-------------------------------------------------------------------*/

#ifndef HARDWARE_SERIALMOD
#define HARDWARE_SERIALMOD

/****	Defines */

/* Output port pin assignments */
/* All other registers are defined locally */

#define	SER_OP4S	REGB(SERA_BASE+0x1E)
#define	SER_OP4C	REGB(SERA_BASE+0x1F)

#define SFX1_S1		0x10
#define SFX1_S2		0x40

/* Mode register 1 bits */
#define	PARITYEVEN	0x00
#define	PARITYODD	0x04
#define	PARITYNONE	0x10
#define	PARITYBITS	0x1c

#define	BITS6		0x01
#define	BITS7		0x02
#define	BITS8		0x03
#define	CHARBITS	0x03

#define RXRTS		0x80
#define RXNONE		0x00
#define RXBITS		0x80

/* Mode register 2 bits */
#define	STOP1		0x07
#define	STOP2		0x0f
#define	STOPBITS	0x0f

#define	TXRTS		0x20
#define	TXCTS		0x10
#define	TXNONE		0x00
#define	TXBITS		0x30

/* Auxiliary control register */
#define	BAUDSET1	0x00
#define	BAUDSET2	0x80
#define	BAUDSETBITS	0x80

/* Baud select */
#define	BAUD50		0
#define	BAUD75		1
#define	BAUD110		2
#define	BAUD134		3
#define	BAUD150		4
#define	BAUD200		5
#define	BAUD300		6
#define	BAUD600		7
#define	BAUD1050	8
#define	BAUD1200	9
#define BAUD1800	10
#define	BAUD2000	11
#define	BAUD2400	12
#define	BAUD4800	13
#define	BAUD7200	14
#define	BAUD9600	15
#define	BAUD19200	16
#define	BAUD38400	17
#define	BAUD57600	18
#define	BAUD76800	19
#define BAUD115200	20

/*
	Spread spectrum clock 40Mhz, with -3.75% spread
	center frequency 40Mhz-(3.75/2)% = 39.25MHZ

	Coldfire UART baud rate clock is 39.25MHZ / 32

		1200 = (39.25MHZ/32) * (1/1200) = 1022		(0x03fe)
		1800 = (39.25MHZ/32) * (1/1800) = 681 		(0x02a9)
		2000 = (39.25MHZ/32) * (1/2000) = 613	 	(0x0265)
		2400 = (39.25MHZ/32) * (1/2400) = 511 		(0x01ff)
		4800 = (39.25MHZ/32) * (1/4800) = 255		(0x00ff)
		7200 = (39.25MHZ/32) * (1/7200) = 170		(0x00aa)
		9600 = (39.25MHZ/32) * (1/9600) = 128		(0x0080)
		19200 = (39.25MHZ/32) * (1/19200) = 64		(0x0040)
		38400 = (39.25MHZ/32) * (1/38400) = 32		(0x0020)
		76800 = (39.25MHZ/32) * (1/76800) = 16		(0x0010)
		115200 = (39.25MHZ/32) * (1/115200 ) = 11  (0x000B)
*/

#define	REG_BAUD1200	0x03fe
#define REG_BAUD1800	0x02a9
#define	REG_BAUD2000	0x0265
#define	REG_BAUD2400	0x01ff
#define	REG_BAUD4800	0x00ff
#define	REG_BAUD7200	0x00aa
#define	REG_BAUD9600	0x0080
#define	REG_BAUD19200	0x0040
#define	REG_BAUD38400	0x0020
#define	REG_BAUD76800	0x0010

#define REG_BAUD115200 	0x000B

/* SERIAL MODULE REGISTERS */

/* Channel A registers */
#define	SER_MCRA	REGBV(MBAR+0x0140) /* Mode Register */
#define SER_UCSRA	REGBV(MBAR+0x0144) /* Clock Select Register */
#define SER_SRA		REGBV(MBAR+0x0144) /* Status Register */
#define SER_UCRA	REGBV(MBAR+0x0148) /* Command Register */
#define SER_TBA		REGBV(MBAR+0x014C) /* Transmit buffer */
#define SER_RBA		REGBV(MBAR+0x014C) /* Receive buffer */
#define SER_UACRA	REGBV(MBAR+0x0150) /* Aux control register */
#define SER_UIPCRA	REGBV(MBAR+0x0150) /* Input port change register */
#define SER_UIMRA	REGBV(MBAR+0x0154) /* Interrupt mask register */
#define SER_UISRA	REGBV(MBAR+0x0154) /* Interrupt status register */
#define SER_UBGMSBA	REGBV(MBAR+0x0158) /* Baud rate gen prescale MSB */
#define SER_UBGLSBA	REGBV(MBAR+0x015C) /* Baud rate gen prescale LSB */
#define SER_UIVRA	REGBV(MBAR+0x0170) /* Interrupt vector register */
#define SER_UIPA	REGBV(MBAR+0x0174) /* Input port register */
#define SER_UOP1A	REGBV(MBAR+0x0178) /* Output port bit set */
#define SER_UOP0A	REGBV(MBAR+0x0178) /* Output port bit reset */

/* Channel B registers */
#define	SER_MCRB	REGB(MBAR+0x0180) /* Mode Register */
#define SER_UCSRB	REGBV(MBAR+0x0184) /* Clock Select Register */
#define SER_SRB		REGBV(MBAR+0x0184) /* Status Register */
#define SER_UCRB	REGB(MBAR+0x0188) /* Command Register */
#define SER_TBB		REGBV(MBAR+0x018C) /* Transmit buffer */
#define SER_RBB		REGBV(MBAR+0x018C) /* Receive buffer */
#define SER_UACRB	REGBV(MBAR+0x0190) /* Aux control register */
#define SER_UIPCRB	REGBV(MBAR+0x0190) /* Input port change register */
#define SER_UIMRB	REGBV(MBAR+0x0194) /* Interrupt mask register */
#define SER_UISRB	REGBV(MBAR+0x0194) /* Interrupt status register */
#define SER_UBGMSBB	REGBV(MBAR+0x0198) /* Baud rate gen prescale MSB */
#define SER_UBGLSBB	REGBV(MBAR+0x019C) /* Baud rate gen prescale LSB */
#define SER_UIVRB	REGBV(MBAR+0x01B0) /* Interrupt vector register */
#define SER_UIPB	REGBV(MBAR+0x01B4) /* Input port register */
#define SER_UOP1B	REGBV(MBAR+0x01B8) /* Output port bit set */
#define SER_UOP0B	REGBV(MBAR+0x01B8) /* Output port bit reset */

/* UCSR (Clock Select Register) */
#define	RXBAUDBITS	0xf0 /* Receiver = Ext clock * 1 */
#define	TXBAUDBITS	0x0f /* Transmitter = Ext clock * 1 */

/* UCR (Command Register) Commands*/
#define	TX_DISABLE_CMD		0x08 /* Disable transmitter */
#define	TX_ENABLE_CMD		0x04 /* Enable transmitter */
#define	TX_RESET_CMD		0x30 /* Reset transmitter */
#define	RX_DISABLE_CMD		0x02 /* Disable receiver */
#define	RX_ENABLE_CMD		0x01 /* Enable receiver */
#define	RX_RESET_CMD		0x20 /* Reset receiver */
#define	ERR_RESET_CMD		0x40 /* Clear delta break in UISR */
#define	ASSRTS_CMD			0x80 /* Reset */
#define	NEGRTS_CMD			0x90 /* Reset and reset mode register pointer */
#define MODE_REG_PTR_CMD	0x10 /* Reset mode register pointer to UMR1 */

/* USR (Status Register) Bits*/
#define	SR_RB			0x80 /* Recieve Break */
#define	SR_FE			0x40 /* Framing Error */
#define	SR_PE			0x20 /* Parity Error */
#define	SR_OE			0x10 /* Overrun Error */

/* UISR (Interrupt Status Register) */
#define	TXRDY			0x01 /* Receiver ready or FIFO full */
#define	RXRDY			0x02 /* Transmitter ready */
#define	DB				0x04 /* Delta Break */
#define	COS				0x80 /* Change of state */

#define	ERROR_BITS	(SR_RB+SR_FE+SR_PE+SR_OE)

#define	SETBITFIELD(REG,FIELD,BITS) REG&=~FIELD; REG|=(BITS & FIELD)

/****	Type Definitions */
typedef	struct	serialvars
{
	WORD	txain;
	WORD	txaout;
	WORD	rxain;
	WORD	rxaout;

	WORD	txbin;
	WORD	txbout;
	WORD	rxbin;
	WORD	rxbout;
	BYTE	base;
} SERIALVARS;

typedef	struct serialservices
{
	BYTE	(*configure)(const DEVICE* dev,BYTE txbaud,BYTE rxbaud,BYTE data,BYTE stop,BYTE parity,BYTE txhs ,BYTE rxhs);
	BYTE	(*tx)(const DEVICE* dev, BYTE ch);
	WORD	(*rx)(const DEVICE* dev);
	BYTE 	(*txempty)(const DEVICE* dev);
	BYTE 	(*rxempty)(const DEVICE* dev);
	void 	(*cleartx)(const DEVICE* dev);
	void 	(*clearrx)(const DEVICE* dev);
	void 	(*setrouting)(const DEVICE* dev, BYTE channel, BYTE route);
} SERIALSERVICES;

typedef	struct	serialcfg
{
	BYTE	ucsra;		/* status register channel A */
	BYTE	uimra;		/* interrupt mask register channel A */
	BYTE	uivra; 		/* interrupt vector register channel A */
	BYTE	ucsrb;		/* status register channel B */
	BYTE	uimrb;		/* interrupt mask register channel B */
	BYTE	uivrb;		/* interrupt vector register channel B */
	BYTE	txbauda;	/* transmit baud rate channel A */
	BYTE	rxbauda;	/* receive baud rate channel A */
	BYTE	bitsa;		/* data bits channel A */
	BYTE	stopa;		/* stopbits channel A */
	BYTE	paritya;	/* parity channel A */
	BYTE	txhsa;		/* transmit handshaking channel A */
	BYTE	rxhsa;		/* receive handshaking channel A */
	BYTE	txbaudb;	/* transmit baud rate channel B */
	BYTE	rxbaudb;	/* receive baud rate channel B */
	BYTE	bitsb;		/* data bits channel B */
	BYTE	stopb;		/* stop bits channel B */
	BYTE	parityb;	/* parity channel B */
	BYTE	txhsb;		/* transmit handshaking channel B */
	BYTE	rxhsb;		/* receive handshaking channel B */
} SERIALCFG;


/****	Prototypes */

	#include	"serialmod.p"

#endif
/*************************************************************************/
